@@ -5,17 +5,23 @@
 # Author          : Johan Vromans
 # Created On      : Thu Sep 15 11:43:40 2016
 # Last Modified By: Johan Vromans
-# Last Modified On: Mon Mar 20 09:52:26 2017
-# Update Count    : 255
+# Last Modified On: Wed Nov  8 19:46:23 2017
+# Update Count    : 257
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
 
 use strict;
 use warnings;
+
+# The FindBin stuff is only used when running in-place.
 use FindBin;
 use lib "$FindBin::Bin/../CPAN";
 use lib "$FindBin::Bin/../lib";
+
+# App::Packager is only used when running packaged.
+use App::Packager;
+
 use App::PDF::Link;
 
 =head1 NAME
